@@ -2,7 +2,7 @@
 Date         : 2022-10-25 15:44:41
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-10-26 11:17:01
+LastEditTime : 2022-10-28 14:30:41
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\__init__.py
@@ -10,5 +10,5 @@ Copyright (c) 2022 by BDFD, All Rights Reserved.
 '''
 
 from execdata.templateproj import add_one
-from execdata.preprocess import encode, split
+from execdata.preprocess import encode, sep, split, strat_split
 from execdata.model_evaluate import model_evaluate
